@@ -1,9 +1,8 @@
 package MooseX::Getopt::Dashes;
-BEGIN {
-  $MooseX::Getopt::Dashes::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: convert underscores in attribute names to dashes
-$MooseX::Getopt::Dashes::VERSION = '0.62';
+
+our $VERSION = '0.78';
+
 use Moose::Role;
 with 'MooseX::Getopt';
 use namespace::autoclean;
@@ -28,15 +27,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Stevan Little Infinity Interactive, Inc
-
 =head1 NAME
 
 MooseX::Getopt::Dashes - convert underscores in attribute names to dashes
 
 =head1 VERSION
 
-version 0.62
+version 0.78
 
 =head1 SYNOPSIS
 
@@ -64,7 +61,7 @@ version 0.62
 
 =head1 DESCRIPTION
 
-This is a version of C<MooseX::Getopt> which converts underscores in
+This is a version of L<MooseX::Getopt> which converts underscores in
 attribute names to dashes when generating command line flags.
 
 You can selectively disable this on a per-attribute basis by supplying
@@ -72,6 +69,17 @@ a L<cmd_flag|MooseX::Getopt::Meta::Attribute/METHODS> argument with
 the command flag you'd like for a given attribute. No underscore to
 dash replacement will be done on the C<cmd_flag>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Getopt>
+(or L<bug-MooseX-Getopt@rt.cpan.org|mailto:bug-MooseX-Getopt@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
