@@ -1,11 +1,9 @@
 package MooseX::Getopt::Meta::Attribute::NoGetopt;
-BEGIN {
-  $MooseX::Getopt::Meta::Attribute::NoGetopt::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: Optional meta attribute for ignoring parameters
-$MooseX::Getopt::Meta::Attribute::NoGetopt::VERSION = '0.62';
-use Moose;
 
+our $VERSION = '0.78';
+
+use Moose;
 extends 'Moose::Meta::Attribute'; # << Moose extending Moose :)
    with 'MooseX::Getopt::Meta::Attribute::Trait::NoGetopt';
 
@@ -24,15 +22,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Stevan Little Infinity Interactive, Inc
-
 =head1 NAME
 
 MooseX::Getopt::Meta::Attribute::NoGetopt - Optional meta attribute for ignoring parameters
 
 =head1 VERSION
 
-version 0.62
+version 0.78
 
 =head1 SYNOPSIS
 
@@ -76,6 +72,17 @@ use this as the B<NoGetopt> alias, like so:
 
   has 'foo' => (metaclass => 'NoGetopt', cmd_flag => 'f');
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Getopt>
+(or L<bug-MooseX-Getopt@rt.cpan.org|mailto:bug-MooseX-Getopt@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
